@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/**
+/*
  * gnome-component-ui.c: Client UI signal multiplexer and verb repository.
  *
  * Author:
@@ -1112,31 +1112,19 @@ impl_set_prop (BonoboUIComponent  *component,
 	       const char         *value,
 	       CORBA_Environment  *opt_ev)
 {
-	BonoboUINode *node;
-	char *parent_path;
-	Bonobo_UIContainer container;
+	char *full_path;
 
 	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
-	container = component->priv->container;
-	g_return_if_fail (container != CORBA_OBJECT_NIL);
+
+	full_path = alloca (strlen (path) + 1 + strlen (prop) + 1);
+	strcpy (full_path, path);
+	strcat (full_path, "#");
+	strcat (full_path, prop);
 
 	bonobo_object_ref (BONOBO_OBJECT (component));
 
-	node = bonobo_ui_component_get_tree (
-		component, path, FALSE, opt_ev);
-
-	g_return_if_fail (node != NULL);
-
-	bonobo_ui_node_set_attr (node, prop, value);
-
-	parent_path = bonobo_ui_xml_get_parent_path (path);
-
-	bonobo_ui_component_set_tree (
-		component, parent_path, node, opt_ev);
-
-	g_free (parent_path);
-
-	bonobo_ui_node_free (node);
+	bonobo_ui_component_set (
+		component, full_path, value, opt_ev);
 
 	bonobo_object_unref (BONOBO_OBJECT (component));
 }
@@ -1186,26 +1174,36 @@ impl_get_prop (BonoboUIComponent *component,
 	       const char        *prop,
 	       CORBA_Environment *opt_ev)
 {
-	BonoboUINode *node;
+	char *full_path;
 	xmlChar *ans;
 	gchar   *ret;
+        CORBA_Environment hack_ev;
 
 	g_return_val_if_fail (BONOBO_IS_UI_COMPONENT (component), NULL);
 
-	node = bonobo_ui_component_get_tree (
-		component, path, FALSE, opt_ev);
+	full_path = alloca (strlen (path) + 1 + strlen (prop) + 1);
+	strcpy (full_path, path);
+	strcat (full_path, "#");
+	strcat (full_path, prop);
 
-	g_return_val_if_fail (node != NULL, NULL);
+	bonobo_object_ref (BONOBO_OBJECT (component));
+
+	if (!opt_ev) {
+		/* Hack to avoid warnings for reading non-existant properties */
+		CORBA_exception_init (&hack_ev);
+		opt_ev = &hack_ev;
+	}
+
+	ans = bonobo_ui_component_get (component, full_path, FALSE, opt_ev);
 
-	ans = bonobo_ui_node_get_attr (node, prop);
 	if (ans) {
 		ret = g_strdup (ans);
 		bonobo_ui_node_free_string (ans);
 	} else
 		ret = NULL;
 
-	bonobo_ui_node_free (node);
-
+	bonobo_object_unref (BONOBO_OBJECT (component));
+	
 	return ret;
 }
 
